#!/usr/bin/env python

"A very simple example application."

import WebStack.Generic
import XSLForms.Resources
import XSLForms.Utils
import os

# Resource classes.

class VerySimpleResource(XSLForms.Resources.XSLFormsResource):

    "A very simple resource providing a hierarchy of editable fields."

    resource_dir = os.path.join(os.path.split(__file__)[0], "Resources")
    encoding = "utf-8"
    template_resources = {
        #"structure" : ("structure_template.xhtml", "structure_output.xsl")
        "structure" : ("structure_multivalue_template.xhtml", "structure_output.xsl")
        }
    transform_resources = {
        #"types" : ["structure_types.xsl"]
        #"types" : ["structure_multivalue_types.xsl"]
        "types" : ["structure_multivalue_types.xsl", "structure_comments.xsl"]
        }
    document_resources = {
        "types" : "structure_types.xml"
        }

    def respond_to_form(self, trans, form):

        """
        Respond to a request having the given transaction 'trans' and the given
        'form' information.
        """

        documents = form.get_documents()

        # Ensure the presence of a document.

        if documents.has_key("structure"):
            structure = documents["structure"]
        else:
            structure = form.new_instance("structure")

        # Add and remove elements according to the selectors found.

        selectors = form.get_selectors()
        XSLForms.Utils.remove_elements(selectors.get("remove2"))
        XSLForms.Utils.add_elements(selectors.get("add2"), "subitem")
        XSLForms.Utils.remove_elements(selectors.get("remove"))
        XSLForms.Utils.add_elements(selectors.get("add"), "item")

        # Transform, adding enumerations/ranges.

        types_xsl_list = self.prepare_transform("types")
        types_xml = self.prepare_document("types")
        structure = self.get_result(types_xsl_list, structure, references={"types" : types_xml})

        # Start the response.

        trans.set_content_type(WebStack.Generic.ContentType("application/xhtml+xml", self.encoding))

        # Ensure that an output stylesheet exists.

        trans_xsl = self.prepare_output("structure")

        # Complete the response.

        self.send_output(trans, [trans_xsl], structure)

# Site map initialisation.

def get_site():

    "Return a simple Web site resource."

    return VerySimpleResource()

# vim: tabstop=4 expandtab shiftwidth=4
